@@ -28,7 +28,7 @@ setup(
       'sio_tools',
       'pandas'
     ],
-    packages=['cytolysis','cytolysis.examples'],
-    package_dir={'cytolysis': 'src', 'cytolysis.examples': 'examples'},
-    package_data={'cytolysis.examples': ['examples/*.txt', 'examples/*.cym']},
+    packages=['cytolysis','cytolysis.example_data'],
+    package_dir={'cytolysis': 'src', 'cytolysis.example_data': 'example_data'},
+    package_data={'cytolysis.example_data': ['*.txt', '*.cym']},
  )
