@@ -23,7 +23,7 @@ try:
 except:
     print("Unable to import Ipyvolume")
 
-__VERSION__ = "0.0.15"
+__VERSION__ = "0.0.16"
 
 """
     A module to analyze cytosim simulations
@@ -275,11 +275,11 @@ class Simulation(list):
             self.plot_all(*args, **kwargs)
             self.show_frame(0)
 
-            play = widgets.Play( interval=interval, value=0, min=0, max=len(self)-1, step=1 )
+            #play = widgets.Play( interval=interval, value=0, min=0, max=len(self)-1, step=1 )
             slider = widgets.IntSlider(value=0, min=0, max=len(self)-1,step=1)
 
-            widgets.jslink((play, 'value'), (slider, 'value'))
-            interact(self.show_frame, number=play)
+            #widgets.jslink((play, 'value'), (slider, 'value'))
+            interact(self.show_frame, number=slider)
             self.show()
-            widgets.HBox([play, slider])
+            #widgets.HBox([play, slider])
 
